@@ -353,7 +353,7 @@ class VariableClAutologin(UserHelper,Variable):
                     _("The autologin is not available with domain workstations")
         except DataVarsError:
             pass
-        return ""
+        return UserHelper.uncompatible(self)
 
 class VariableClInstallAutoupdateSet(Variable):
     """
@@ -533,8 +533,8 @@ class VariableOsGrub2Path(Variable):
             return grubInstall
         # find grub-install and check, that this is grub2-install (ver 1.99)
         grubInstall = getProgPath('/usr/sbin/grub-install')
-        if grubInstall and filter(lambda x:"1.99" in x or "2.00" in x,
-                           process(grubInstall,'-v')):
+        if grubInstall and filter(lambda x:"1.99" in x or "2." in x,
+                           process(grubInstall,'--version')):
             return grubInstall
         return ""
 
@@ -662,13 +662,25 @@ class VariableOsInstallUefiSet(Variable):
 
     def uncompatible(self):
         """
-        Network setting up unavailable for flash installation
+        Uncompatible with autopartition
         """
         if self.Get('cl_autopartition_set') == "on":
             return \
                 _("The layout is not available with autopartitioning")
+        if self.Get('os_install_root_type') == 'flash':
+            return \
+                _("This option not used for Flash install")
         return ""
 
+class VariableOsInstallUefiBriefSet(VariableOsInstallUefiSet):
+    def uncompatible(self):
+        if self.Get('os_install_root_type') == 'flash':
+            return _("This option not used for Flash install")
+        return ""
+    
+    def get(self):
+        return self.Get('os_install_uefi_set')
+
 class VariableOsInstallGrubTerminal(Variable):
     """
     Gfxmode
@@ -759,35 +771,35 @@ class FlashUncompatible:
 try:
     import calculate.update.variables.update as update
 
-    class VariableClInstallAutocheckSet(update.VariableClUpdateAutocheckSet,
-                                        FlashUncompatible):
+    class VariableClInstallAutocheckSet(FlashUncompatible,
+                                        update.VariableClUpdateAutocheckSet):
         def get(self):
             return self.Get('update.cl_update_autocheck_set')
 
-    class VariableClInstallAutocheckInterval(
-            update.VariableClUpdateAutocheckInterval, FlashUncompatible):
+    class VariableClInstallAutocheckInterval(FlashUncompatible,
+            update.VariableClUpdateAutocheckInterval):
         def get(self):
             return self.Get('update.cl_update_autocheck_interval')
 
-    class VariableClInstallCleanpkgSet(
-        update.VariableClUpdateCleanpkgSet, FlashUncompatible):
+    class VariableClInstallCleanpkgSet(FlashUncompatible,
+        update.VariableClUpdateCleanpkgSet):
         def get(self):
             return self.Get('update.cl_update_cleanpkg_set')
 
-    class VariableClInstallOtherSet(
-        update.VariableClUpdateOtherSet, FlashUncompatible):
+    class VariableClInstallOtherSet(FlashUncompatible,
+        update.VariableClUpdateOtherSet):
         def get(self):
             return self.Get('update.cl_update_other_set')
 
 except ImportError:
-    class VariableClInstallAutocheckSet(Variable, FlashUncompatible):
+    class VariableClInstallAutocheckSet(FlashUncompatible, Variable):
         value = "off"
 
-    class VariableClInstallAutocheckInterval(Variable, FlashUncompatible):
+    class VariableClInstallAutocheckInterval(FlashUncompatible, Variable):
         value = ""
 
-    class VariableClInstallCleanpkgSet(Variable, FlashUncompatible):
+    class VariableClInstallCleanpkgSet(FlashUncompatible, Variable):
         value = "off"
 
-    class VariableClInstallOtherSet(Variable, FlashUncompatible):
+    class VariableClInstallOtherSet(FlashUncompatible, Variable):
         value = "off"
